# "Send Character" action part plugins

A plugin for Visionaire Studio 5 that provides several action parts which let you send characters around in your scenes in interesting and helpful ways.

## Send Character to Random Position

![Send Character to Random Position](usage_examples/send-character-to-random-position_usage-example.png "Send Character to Random Position")

Sends the specified character to a random position in the current scene, while avoiding walking too far, and ensuring the new position lies within the scene's way system's border polygon.

Quite nice to breathe some life into a market or other crowded places, and have NPCs roam a bit.

## "Send Character near" action parts

These action parts are quite helpful to gather characters around, or follow, something.

All computed destination positions are checked to be inside the scene's way system's border polygon.

### Send Character near Position

![Send Character Near Position](usage_examples/send-character-near-position_usage-example.png "Send Character Near Position")

Sends the specified character towards a specified position, but has the character stop in a certain distance from it. Due to limitations of Action Part Plugins' GUI, this action part does not have option "Wait until character stops". Instead, create a dedicated "Wait until character stops" action part after it.

### Send Character near Object

![Send Character Near Object](usage_examples/send-character-near-object_usage-example.png "Send Character Near Object")

Sends the specified character towards a specified object, but has the character stop in a certain distance from it.

### Send Character near Character

![Send Character Near Character](usage_examples/send-character-near-character_usage-example.png "Send Character Near Character")

Sends the specified character towards a specified character, but has the character stop in a certain distance from it.

This uses the target character's `Destination` position. Thus, you can predefine how characters will group together, even before they have reached their destination. For example: Send Character 1 to a position (with no waiting), and use this action part to send Character 2 and Character 3 towards Character 1 (both with no waiting). Add additional action parts to wait until all three characters have stopped walking. Character 1 will now stand at the defined position, with Characters 2 and 3 near Character 1.

## "Send Character relative" action parts

These action parts send a character to a destination, but stopping at a relative position from the actual destination position.

This is nice to e.g. group characters near to each other or to an object, especially if the destination position is not known at the time of programming, or is bound to change. The relative position is defined using the "Offset" parameter. The offset values are simply added to the actual destination position.

### Send Character Relative to Object

![Send Character Relative to Object](usage_examples/send-character-relative-to-object_usage-example.png "Send Character Relative to Object")

Sends the specified character towards a specified object, but has the character stop at a relative position from it.

### Send Character Relative to Character

![Send Character Relative to Character](usage_examples/send-character-relative-to-character_usage-example.png "Send Character Relative to Character")

Sends the specified character towards a specified character, but has the character stop at a relative position from it.

This uses the target character's `Destination` position. Thus, you can predefine how characters will group together, even before they have reached their destination. For example: Send Character 1 to a position (with no waiting), and use this action part to send Character 2 and Character 3 to positions relative to Character 1 (both with no waiting). Add additional action parts to wait until all three characters have stopped walking. Character 1 will now stand at the defined position, with Characters 2 and 3 positioned relatively to Character 1.

## Possible improvements

* Currently, if the computed target position is outside the waysystem's border polygon, the character won't move at all. Coming up with a valid substitute position would be preferrable.
* Since way system borders can include more than one polygon, it would be nice to add support for that. Each border polygon will have to be tested separately.

## Version history

### 1.3.3

* `sendCharacterToNearObjectPos()` now accepts additional parameter to optionally make it use `targetObj.Destination` as `targetPosition`: this is now used in actionparts `SENDCHARNEARCHAR` and `SENDCHARRELTOCHAR`
* Action parts now show the "Wait" setting in their name
* Better translations
* Renamed some action part plugin name symbols (fixed typo)

### 1.3.1

* Bugfixes

### 1.3

* Added action parts "Send Character Relative to Object", and "Send Character Relative to Character"

### 1.2

* Bugfixes

### 1.1

* Added action parts "Send Character near Position", "Send Character near Object", and "Send Character near Character"

### 1.0

* First version of "Send Character to Random Position"

## Copyright / license

Released under MIT License

Copyright (c) 2025 Frank Willeke

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
